Skip to content

Retrieves effective sample size estimates for all parameters from a model fitted with bgm() or bgmCompare().

Usage

extract_ess(bgms_object)

Arguments

bgms_object

A fitted model object of class bgms (from bgm()) or bgmCompare (from bgmCompare()).

Value

A named list with ESS values for each parameter type present in the model (e.g., main, pairwise, indicator).