Skip to content

Specifies a Normal(0, scale) prior on model parameters. Produces lighter-tailed shrinkage than the Cauchy prior and is better suited for simulation-based calibration (SBC) studies. Can be used for interactions, thresholds, or continuous means.

Usage

normal_prior(scale = 1)

Arguments

scale

Positive numeric. Standard deviation of the normal distribution. Default: 1.

Value

An object of class "bgms_parameter_prior" with family = "normal".

Examples

normal_prior()
#> Parameter prior: Normal(0, 1)
normal_prior(scale = 0.5)
#> Parameter prior: Normal(0, 0.5)