Retrieves the prior specification used for inclusion indicators in a
model fitted with bgm() (edge indicators) or bgmCompare()
(difference indicators).
Arguments
- bgms_object
A fitted model object of class
bgms(frombgm()) orbgmCompare(frombgmCompare()).
Value
A named list describing the prior structure, including the prior type and any hyperparameters.
- bgms
Requires
edge_selection = TRUE. Returns a list with the prior type ("Bernoulli","Beta-Bernoulli", or"Stochastic-Block") and associated hyperparameters.- bgmCompare
Requires
difference_selection = TRUE. Returns the difference prior specification.
See also
bgm(), bgmCompare(), extract_indicators()
Other extractors:
extract_arguments(),
extract_category_thresholds(),
extract_ess(),
extract_group_params(),
extract_indicators(),
extract_log_odds(),
extract_main_effects(),
extract_pairwise_interactions(),
extract_partial_correlations(),
extract_posterior_inclusion_probabilities(),
extract_precision(),
extract_rhat(),
extract_sbm()