Extract Pairwise Interaction Samples
Source:R/extractor_functions.R
extract_pairwise_interactions.RdRetrieves posterior samples of pairwise interaction parameters from a
model fitted with bgm() or bgmCompare().
Arguments
- bgms_object
A fitted model object of class
bgms(frombgm()) orbgmCompare(frombgmCompare()).
Value
A matrix with one row per post-warmup iteration and one column per edge, containing posterior samples of interaction strengths.
- bgms
Columns correspond to all unique variable pairs.
- bgmCompare
Columns correspond to the baseline pairwise interaction parameters.
See also
bgm(), bgmCompare(), extract_main_effects()
Other extractors:
extract_arguments(),
extract_category_thresholds(),
extract_ess(),
extract_group_params(),
extract_indicator_priors(),
extract_indicators(),
extract_log_odds(),
extract_main_effects(),
extract_partial_correlations(),
extract_posterior_inclusion_probabilities(),
extract_precision(),
extract_rhat(),
extract_sbm()