Specifies a Normal(0, scale) prior on model parameters. Produces lighter-tailed shrinkage than the Cauchy prior and is better suited for simulation-based calibration (SBC) studies. Can be used for interactions, thresholds, or continuous means.
See also
cauchy_prior, beta_prime_prior,
bgm
Other prior-constructors:
bernoulli_prior(),
beta_bernoulli_prior(),
beta_prime_prior(),
cauchy_prior(),
exponential_prior(),
gamma_prior(),
sbm_prior()