Specifies a Stochastic Block Model (SBM) prior for inclusion indicators. Variables are assigned to latent clusters, with separate Beta priors on within-cluster and between-cluster inclusion probabilities.
Usage
sbm_prior(
alpha = 1,
beta = 1,
alpha_between = 1,
beta_between = 1,
dirichlet_alpha = 1,
lambda = 1
)Arguments
- alpha
Positive numeric. First shape parameter of the Beta distribution for within-cluster edges. Default:
1.- beta
Positive numeric. Second shape parameter of the Beta distribution for within-cluster edges. Default:
1.- alpha_between
Positive numeric. First shape parameter of the Beta distribution for between-cluster edges. Default:
1.- beta_between
Positive numeric. Second shape parameter of the Beta distribution for between-cluster edges. Default:
1.- dirichlet_alpha
Positive numeric. Concentration parameter of the Dirichlet prior on cluster assignments. Default:
1.- lambda
Positive numeric. Rate parameter of the zero-truncated Poisson prior on the number of clusters. Default:
1.
See also
bernoulli_prior, beta_bernoulli_prior,
bgm
Other prior-constructors:
bernoulli_prior(),
beta_bernoulli_prior(),
beta_prime_prior(),
cauchy_prior(),
exponential_prior(),
gamma_prior(),
normal_prior()